aboutsummaryrefslogtreecommitdiffstats
path: root/install/upgrade_1.3.1.php
diff options
context:
space:
mode:
authornikrou <nikrou@piwigo.org>2009-11-16 19:17:01 +0000
committernikrou <nikrou@piwigo.org>2009-11-16 19:17:01 +0000
commit8a299654501db00316a56efda76448a6bb3975e1 (patch)
treeb34f9693380c3e4a69d7c9c45c011fb327560be1 /install/upgrade_1.3.1.php
parent9a773f003c2c88f3916942b65c36912ff81cecf6 (diff)
Feature 928 resolved.
Replace include/mysql.inc.php by include/config_database.inc.php to be independant of database engine Rename database configurations variables by ones in $conf array. git-svn-id: http://piwigo.org/svn/trunk@4280 68402e56-0260-453c-a942-63ccdbb3a9ee
Diffstat (limited to 'install/upgrade_1.3.1.php')
-rw-r--r--install/upgrade_1.3.1.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/install/upgrade_1.3.1.php b/install/upgrade_1.3.1.php
index 69257dc5c..40657c7f7 100644
--- a/install/upgrade_1.3.1.php
+++ b/install/upgrade_1.3.1.php
@@ -579,7 +579,7 @@ UPDATE '.CATEGORIES_TABLE.'
}
// load the config file
-$config_file = PHPWG_ROOT_PATH.'include/mysql.inc.php';
+$config_file = PHPWG_ROOT_PATH.'include/config_database.inc.php';
$config_file_contents = @file_get_contents($config_file);
if ($config_file_contents === false)
{
@@ -595,7 +595,7 @@ if (!is_writable($config_file))
die('FILE NOT WRITABLE '.$config_file);
}
// changes to write in mysql.inc.php
array_push($mysql_changes, 'define(\'PHPWG_INSTALLED\', true);');
// Send infos
@@ -595,7 +595,7 @@ if (!is_writable($config_file))
die('FILE NOT WRITABLE '.$config_file);
}
-// changes to write in mysql.inc.php
+// changes to write in config_database.inc.php
array_push($mysql_changes, 'define(\'PHPWG_INSTALLED\', true);');
// Send infos